fn compute_x(
credentials: &Credentials,
account_key: &AccountKey,
srp_info: &SrpInfo,
) -> Result<[u8; 32], OnePasswordError>Expand description
Derives SRP x, which proves we know the password without sending it.
fn compute_x(
credentials: &Credentials,
account_key: &AccountKey,
srp_info: &SrpInfo,
) -> Result<[u8; 32], OnePasswordError>Derives SRP x, which proves we know the password without sending it.