fn from_server_hex(hex: &str) -> Result<BoxedUint, OnePasswordError>Expand description
Parses a value the server sent in the encoding above.
fn from_server_hex(hex: &str) -> Result<BoxedUint, OnePasswordError>Parses a value the server sent in the encoding above.