fn validate_b(shared_b: &BoxedUint) -> Result<(), OnePasswordError>Expand description
Rejects a server B that is 0 or 1 modulo N, the two values the web client refuses.
fn validate_b(shared_b: &BoxedUint) -> Result<(), OnePasswordError>Rejects a server B that is 0 or 1 modulo N, the two values the web client refuses.